@@ -4,7 +4,7 @@
 //!
 //! The basic idea is that hash maps are expensive to
 //! insert and lookup for small numbers of entries
-//! but effective for lager numbers.
+//! but effective for larger numbers.
 //!
 //! So for smaller maps, we picked 32 entries as a rule
 //! of thumb, we simply store data in a list of tuples.
@@ -767,6 +767,39 @@ where
         }
     }
 
+    /// Removes a key from the map, returning the stored key and value if the
+    /// key was previously in the map.
+    ///
+    /// The key may be any borrowed form of the map's key type, but
+    /// [`Hash`] and [`Eq`] on the borrowed form *must* match those for
+    /// the key type.
+    ///
+    /// [`Eq`]: ../../std/cmp/trait.Eq.html
+    /// [`Hash`]: ../../std/hash/trait.Hash.html
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use halfbrown::HashMap;
+    ///
+    /// let mut map = HashMap::new();
+    /// map.insert(1, "a");
+    /// assert_eq!(map.remove_entry(&1), Some((1, "a")));
+    /// assert_eq!(map.remove(&1), None);
+    /// ```
+    #[inline]
+    pub fn remove_entry<Q: ?Sized>(&mut self, k: &Q) -> Option<(K, V)>
+    where
+        K: Borrow<Q>,
+        Q: Hash + Eq,
+    {
+        match &mut self.0 {
+            HashMapInt::Map(m) => m.remove_entry(k),
+            HashMapInt::Vec(m) => m.remove_entry(k),
+            HashMapInt::None => unreachable!(),
+        }
+    }
+
     /// Retains only the elements specified by the predicate.
     ///
     /// In other words, remove all pairs `(k, v)` such that `f(&k, &mut v)` returns `false`.
